def dft_phase(t, y, freq, verbose=False):
    """A discrete fourier transform (DFT) calculates the amplitude and phase of a frequency.
    Normally we discard the phase component. Here, we only want the phase, and the DFT provides it.
    Takes times (t) and brightness variations (y) as well as the frequencies (freq) we are interested in.
    We don't even calculate the full DFT. We only calculate the sines and cosines of exact freqs of interest."""

    freq = np.asarray(freq)
    
    # Not really necessary, but just in case an empty freq array is sent...
    if freq.ndim == 0:
        freq = freq[None]

    # use np arrays because it's computationally quicker.
    t = np.array(t)
    y = np.array(y)
    phase = []
    for f in freq:
        arg = 2.0 * np.pi * f * t
        ft_real = np.sum(y * np.cos(arg))
        ft_imag = np.sum(y * np.sin(arg))

        # use an arctan function to get the phase
        phase.append(np.arctan2(ft_imag,ft_real))
    return phase
