# lines 6-7 are modified, 40-49 are new, 51 is modified, 53 is modified

def calculate_time_delays(times,mags,freqs,subdivision_size=10):
    """Calculates the mid-times of slices of subdivision_size (days), given arrays of observation times, mags, and a list of freqs."""

    # We need a list to store the mid-times, one to store the phases, and another to store the time delays
    time_midpoints, phases, time_delays = [], [], []

    # we need lists to store the times and mags of the current slice
    time_slice, mag_slice = [], []

    # we will need to explicitly set our starting time
    time_0 = 0

    # loop over every point in the lightcurve
    for t, y in zip(times, mags):
        # add the time and mag data to the current slice
        time_slice.append(t)
        mag_slice.append(y)

        # we define a new subdivision once it reaches subdivision_size
        if t - time_0 > subdivision_size:
            # append the time midpoint of the subdivision
            time_midpoints.append(np.mean(time_slice))
            
            # determine and add the phases for each frequency
            # the dft_phase function takes times, mags and our freq list
            phis = dft_phase(time_slice, mag_slice, freqs)
            phases.append(phis)

            # reset time zero to be the current time, so we start a new loop for the next subdivision.
            time_0 = t

            # similarly, we recreate empty lists for times and mags
            time_slice, mag_slice = [], []

    phases = np.array(phases).T


    for ph, f in zip(phases, freqs):
        # unwrap the phases, it's good practice and sometimes necessary
        ph = np.unwrap(ph)

        # calculate time delay, converting units from days to seconds
        td = 86400 * ph / (2*np.pi*f)

        # subtract the mean TD, add it to the array of TDs
        td -= np.mean(td)
        time_delays.append(td)

    return time_midpoints, time_delays

mid_times, *taus = calculate_time_delays(times,mags,freq_out,10)
